Platform
A Data Store
Your platform provides access to all of the underlying data stores and platform-scoped objects. You can also store data on your platform data store itself, if you wish.
When you authenticate to Cloud CMS, you are given access to your platform. You can only authenticate to one platform at a time. This is because clients are scoped to a single platform. When you authenticate using a client key and secret, you inform the Gitana driver which platform to connect to.
| Note |
Drop in one of our language drivers to accelerate your development.
Here are links to some of our popular Cookbooks to help you get started!
|
Data Stores
A Platform is a parent data store which contains the following child data stores:
Objects
This Platform contains the following objects:
Properties
The following properties are available:
| Property |
Type |
Default |
Read-Only |
Description |
| _doc |
string |
|
No |
The primary ID |
| _system |
object |
|
No |
Metadata maintained by the system |
| accessTokenValidity |
number |
|
No |
|
| antivirusEnabled |
boolean |
|
No |
|
| authenticationMaxAttempts |
number |
|
No |
|
| authenticationResetTimeout |
number |
|
No |
|
| binaryStorageProviderType |
string |
|
No |
The type identifier for the binary storage provider that backs this data store |
| datastoreId |
string |
|
Yes |
The ID of the data store |
| datastoreTypeId |
string |
|
Yes |
The data store type identifier |
| description |
string |
|
No |
A description of the data store |
| enableAuthorities |
boolean |
true |
No |
Whether to check access control rights for principals against this data store |
| locked |
boolean |
|
Yes |
Whether the data store is presently locked. If the data store is locked, then write operations against it will block. |
| lockedBy |
string |
|
No |
The principal that holds the lock (if the data store is locked) |
| maxsize |
number |
|
No |
The maximum allowed allocation size (on disk) of the data store in bytes. If this size of the data store exceeds this value, write operations will fail. A value of -1 indicates that there is no upper limit. |
| objectcount |
number |
|
No |
The number of objects stored within the data store. This includes system-maintained objects. This value is updated periodically and may not be precise at the moment it is read. |
| ownerRegistrarId |
string |
|
No |
|
| ownerTenantId |
string |
|
No |
|
| platformObjectCount |
number |
|
No |
|
| platformSize |
number |
|
No |
|
| refreshTokenRaceConditionWindowMs |
number |
|
No |
|
| refreshTokenValidity |
number |
|
No |
|
| sessionTimeout |
number |
|
No |
|
| size |
number |
|
Yes |
The last-recorded allocation size (on disk) of the data store in bytes. This value is updated periodically and may not be precise at the moment it is read. |
| statisticsDate |
object |
|
No |
Records the time when statistics were last run against the data store. Statistics are run periodically to calculate the data store size and object allocations. |
| statisticsDirty |
boolean |
|
Yes |
Whether writes have occurred against this data store since the last time statistics were run. This signals to the system that statistics need to be collected at the next available opportunity. |
| title |
string |
|
No |
The title of the data store |
Methods
The following methods are available:
Actives Deployment
GET /ref/deployment/actives
Parameters
| Name |
Required |
Type |
Description |
| ref |
true |
string |
|
Actives Deployment
POST /ref/deployment/actives
Parameters
This function has no parameters.
Add Team Member
Adds a principal as a member of a Team against the given platform
POST /teams/{teamKey}/members/add
Parameters
| Name |
Required |
Type |
Description |
| teamKey |
true |
string |
The key identifier for the team |
| id |
true |
string |
|
Response
{
"type": "object",
"description": "Result Map",
"properties": {
"total_rows": {
"type": "number"
},
"offset": {
"type": "number"
},
"size": {
"type": "number"
},
"rows": {
"type": "array",
"items": {
"type": "object"
}
}
}
}
Attachments Data
GET /jobs/{jobId}/data/attachments
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
Attachments Data
POST /jobs/{jobId}/data/attachments
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
Attachments Result
POST /jobs/{jobId}/result/attachments
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
Attachments Result
GET /jobs/{jobId}/result/attachments
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
Check Access
POST /access/check
Parameters
This function has no parameters.
Check Membership
Checks whether a principal belongs to a Team for the given platform
POST /teams/{teamKey}/members/check
Parameters
| Name |
Required |
Type |
Description |
| teamKey |
true |
string |
The key identifier for the team |
| id |
true |
string |
|
Response
{
"type": "object",
"description": "Belongs",
"extends": "status",
"properties": {
"belongs": {
"type": "boolean"
},
"ok": null
}
}
Check Permission
Checks whether one or more authorities against the specified platform are granted for a given set of users
POST /permissions/{permissionId}/check
Parameters
| Name |
Required |
Type |
Description |
| permissionId |
true |
string |
The ID of the permission |
| id |
true |
string |
|
Response
{
"$ref": "#/components/schemas/checkPermission"
}
Check Single Authority
Checks whether a single authority is granted against the specified platform for the given user
POST /authorities/{authorityId}/check
Parameters
| Name |
Required |
Type |
Description |
| authorityId |
true |
string |
The ID or authority key for the authority |
| id |
true |
string |
|
Response
{
"type": "object",
"description": "Check",
"extends": "status",
"properties": {
"check": {
"type": "boolean"
},
"ok": null
}
}
Check multiple Authorities
Checks whether one or more authorities against the specified platform are granted for a given set of users
POST /authorities/check
Parameters
This function has no parameters.
Response
{
"type": "object",
"description": "Check Multiple Authorities Out",
"properties": {
"checks": {
"type": "array",
"items": {
"type": "object",
"properties": {
"permissionedId": {
"type": "string"
},
"principalId": {
"type": "string"
},
"authorityId": {
"type": "string"
},
"result": {
"type": "boolean"
}
}
}
}
}
}
Clear Activities
POST /activities/clear
Parameters
This function has no parameters.
Clear Logs
POST /logs/clear
Parameters
This function has no parameters.
Context Oneteam
POST /oneteam/context
Parameters
This function has no parameters.
Create Log
POST /logs
Parameters
This function has no parameters.
Create Role
Creates a role for the current platform
POST /roles
Parameters
| Name |
Required |
Type |
Description |
| HTTP Payload |
true |
string |
HTTP Payload |
Response
{
"type": "object",
"description": "Status of Operation",
"properties": {
"ok": {
"type": "boolean",
"description": "Indicates whether the operation succeeded or not"
}
}
}
Create a Team
Creates a Team against the given platform
POST /teams
Parameters
This function has no parameters.
Response
{
"type": "object",
"extends": "document",
"description": "Team",
"properties": {
"teamableObjectTypeId": {
"type": "string",
"readonly": true
},
"teamableObjectId": {
"type": "string",
"readonly": true
},
"key": {
"type": "string"
},
"groupId": {
"type": "string"
},
"groupDomainId": {
"type": "string"
},
"roleKeys": {
"type": "array",
"items": {
"type": "string"
}
},
"_doc": null,
"_system": null
}
}
Delete Attachment
Deletes an attachment
DELETE /tenant/attachments/{attachmentId}
Parameters
| Name |
Required |
Type |
Description |
| attachmentId |
true |
string |
|
Delete Attachment
DELETE /jobs/{jobId}/result/attachments/{attachmentId}
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
| attachmentId |
true |
string |
|
Delete Attachment
DELETE /jobs/{jobId}/data/attachments/{attachmentId}
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
| attachmentId |
true |
string |
|
Delete Role
Deletes a role for the current platform
DELETE /roles/{roleKeyOrId}
Parameters
| Name |
Required |
Type |
Description |
| roleKeyOrId |
true |
string |
|
Response
{
"type": "object",
"description": "Status of Operation",
"properties": {
"ok": {
"type": "boolean",
"description": "Indicates whether the operation succeeded or not"
}
}
}
Delete Role
Deletes a role for the current platform
POST /roles/{roleKeyOrId}/delete
Parameters
| Name |
Required |
Type |
Description |
| roleKeyOrId |
true |
string |
|
Response
{
"type": "object",
"description": "Status of Operation",
"properties": {
"ok": {
"type": "boolean",
"description": "Indicates whether the operation succeeded or not"
}
}
}
Deletes a Team
Deletes a Team against the given platform
DELETE /teams/{teamKey}
Parameters
| Name |
Required |
Type |
Description |
| teamKey |
true |
string |
The key identifier for the team |
Response
{
"type": "object",
"description": "Status of Operation",
"properties": {
"ok": {
"type": "boolean",
"description": "Indicates whether the operation succeeded or not"
}
}
}
Deploy Ref
POST /ref/deploy
Parameters
This function has no parameters.
Diff Ref
GET /ref/diff
Parameters
| Name |
Required |
Type |
Description |
| source |
true |
string |
|
| target |
true |
string |
|
Download Attachment
Downloads an attachment
GET /tenant/attachments/{attachmentId}
Parameters
| Name |
Required |
Type |
Description |
| attachmentId |
true |
string |
|
Download Preview
Downloads a preview stream of a tenant attachment
GET /tenant/preview/{name}
Parameters
| Name |
Required |
Type |
Description |
| name |
true |
string |
|
Email Export
POST /ref/exports/{exportId}/email
Parameters
| Name |
Required |
Type |
Description |
| exportId |
true |
string |
|
Export Platform
Starts an export job for this resource
POST /export
Parameters
| Name |
Required |
Type |
Description |
| groupId |
false |
string |
The Group ID to be assigned to the exported archive |
| artifactId |
false |
string |
The Artifact ID to be assigned to the exported archive |
| versionId |
false |
string |
The Version ID to be assigned to the exported archive |
| vaultId |
false |
string |
The ID of the vault where the exported archive should be saved |
| schedule |
false |
string |
Whether to run the job immediately or in the background (either 'synchronous' or 'asynchronous') |
Response
{
"type": "object",
"description": "Export Configuration",
"properties": {
"startDate": {
"type": "object",
"description": "Only include objects whose modification date is after this time (epoch millis). This is used for partial or rolling exports."
},
"endDate": {
"type": "object",
"description": "Only include objects whose modification date is before this time (epoch millis). This is used for partial or rolling exports."
},
"startChangeset": {
"type": "string",
"description": "Only include data that is relevant to changesets at or beyond the specified changeset."
},
"endChangeset": {
"type": "string",
"description": "Only include data that is relevant to changesets at or before the specified changeset."
},
"includeACLs": {
"type": "boolean",
"default": true,
"description": "Whether to include ACLs during export."
},
"includeTeams": {
"type": "boolean",
"default": true,
"description": "Whether to include Teams during export."
},
"includeActivities": {
"type": "boolean",
"default": true,
"description": "Whether to include Activities during export."
},
"includeBinaries": {
"type": "boolean",
"default": true,
"description": "Whether to include Binaries for data stores during export."
},
"includeAttachments": {
"type": "boolean",
"default": true,
"description": "Whether to include Attachments for Attachables during export."
},
"artifactDependencies": {
"type": "array",
"items": {
"type": "object"
}
},
"artifactIncludes": {
"type": "array",
"items": {
"type": "object"
}
},
"forceIncludes": {
"type": "boolean"
}
}
}
Export Transfer
POST /transfer/export
Parameters
This function has no parameters.
Generate Export
POST /ref/exports/{exportId}/generate
Parameters
| Name |
Required |
Type |
Description |
| exportId |
true |
string |
|
Get Team
Retrieves a Team against the given platform
GET /teams/{teamKey}
Parameters
| Name |
Required |
Type |
Description |
| teamKey |
true |
string |
The key identifier for the team |
Response
{
"type": "object",
"extends": "document",
"description": "Team",
"properties": {
"teamableObjectTypeId": {
"type": "string",
"readonly": true
},
"teamableObjectId": {
"type": "string",
"readonly": true
},
"key": {
"type": "string"
},
"groupId": {
"type": "string"
},
"groupDomainId": {
"type": "string"
},
"roleKeys": {
"type": "array",
"items": {
"type": "string"
}
},
"_doc": null,
"_system": null
}
}
Grant Authority
Grants an authority against the specified platform to a given user
POST /authorities/{authorityId}/grant
Parameters
| Name |
Required |
Type |
Description |
| authorityId |
true |
string |
The ID or authority key for the authority |
| id |
true |
string |
|
Response
{
"type": "object",
"description": "Status of Operation",
"properties": {
"ok": {
"type": "boolean",
"description": "Indicates whether the operation succeeded or not"
}
}
}
Grant Authority to Team
Assigns an Authority to a Team for the given platform
POST /teams/{teamKey}/authorities/{authorityId}/grant
Parameters
| Name |
Required |
Type |
Description |
| teamKey |
true |
string |
The key identifier for the team |
| authorityId |
true |
string |
The ID or authority key for the authority |
Response
{
"type": "object",
"description": "Status of Operation",
"properties": {
"ok": {
"type": "boolean",
"description": "Indicates whether the operation succeeded or not"
}
}
}
Import
POST /import
Parameters
This function has no parameters.
Import Transfer
POST /transfer/import
Parameters
| Name |
Required |
Type |
Description |
| target |
true |
string |
|
Kill Job
POST /jobs/{jobId}/kill
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
Killall Jobs
POST /jobs/killall
Parameters
This function has no parameters.
List Activities
GET /activities
Parameters
This function has no parameters.
List Attachments
Lists the attachments for the current tenant
GET /tenant/attachments
Parameters
This function has no parameters.
List Dependencies
GET /jobs/{jobId}/dependencies
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
List Logs
GET /logs
Parameters
This function has no parameters.
List Logs
GET /jobs/{jobId}/logs
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
List Roles
Lists the roles for the current platform
GET /roles
Parameters
| Name |
Required |
Type |
Description |
| inherited |
false |
string |
|
Response
{
"type": "object",
"description": "Result Map",
"properties": {
"total_rows": {
"type": "number"
},
"offset": {
"type": "number"
},
"size": {
"type": "number"
},
"rows": {
"type": "array",
"items": {
"$ref": "#/components/schemas/resultmap"
}
}
}
}
List Team Authorities
Retrieves a list of the authorities defined to be granted by a Team
GET /teams/{teamKey}/authorities
Parameters
| Name |
Required |
Type |
Description |
| teamKey |
true |
string |
The key identifier for the team |
Response
{
"type": "object",
"description": "List of Authorities",
"properties": {
"authorities": {
"type": "array",
"items": {
"type": "string"
}
}
}
}
List Teams
Lists the Teams against the given platform
GET /teams
Parameters
This function has no parameters.
Response
{
"type": "object",
"description": "Result Map",
"properties": {
"total_rows": {
"type": "number"
},
"offset": {
"type": "number"
},
"size": {
"type": "number"
},
"rows": {
"type": "array",
"items": {
"type": "object"
}
}
}
}
Lists Team Members
Lists the members of a Team against the given platform
GET /teams/{teamKey}/members
Parameters
| Name |
Required |
Type |
Description |
| teamKey |
true |
string |
The key identifier for the team |
Response
{
"type": "object",
"description": "Result Map",
"properties": {
"total_rows": {
"type": "number"
},
"offset": {
"type": "number"
},
"size": {
"type": "number"
},
"rows": {
"type": "array",
"items": {
"type": "object"
}
}
}
}
Logfile Logs
GET /logs/logfile
Parameters
This function has no parameters.
Lookup Access
POST /access/lookup
Parameters
This function has no parameters.
Merge Ref
POST /ref/merge
Parameters
| Name |
Required |
Type |
Description |
| ref |
true |
string |
|
Query
Queries for matches
POST /jobs/results/query
Parameters
| Name |
Required |
Type |
Description |
| sort |
false |
object |
Defines how to sort fields in the result set |
| skip |
false |
number |
Skips the result set cursor ahead the specified number of records |
| limit |
false |
number |
Specifies the number of records to be handed back in the result set |
This method supports pagination.
Response
{
"type": "object",
"description": "Result Map",
"properties": {
"total_rows": {
"type": "number"
},
"offset": {
"type": "number"
},
"size": {
"type": "number"
},
"rows": {
"type": "array",
"items": {
"$ref": "#/components/schemas/resultmap"
}
}
}
}
Query
Queries for matches
POST /jobs/data/query
Parameters
| Name |
Required |
Type |
Description |
| sort |
false |
object |
Defines how to sort fields in the result set |
| skip |
false |
number |
Skips the result set cursor ahead the specified number of records |
| limit |
false |
number |
Specifies the number of records to be handed back in the result set |
This method supports pagination.
Response
{
"type": "object",
"description": "Result Map",
"properties": {
"total_rows": {
"type": "number"
},
"offset": {
"type": "number"
},
"size": {
"type": "number"
},
"rows": {
"type": "array",
"items": {
"$ref": "#/components/schemas/resultmap"
}
}
}
}
Query
Queries for matches
POST /jobs/{jobId}/logs/query
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
| sort |
false |
object |
Defines how to sort fields in the result set |
| skip |
false |
number |
Skips the result set cursor ahead the specified number of records |
| limit |
false |
number |
Specifies the number of records to be handed back in the result set |
This method supports pagination.
Response
{
"type": "object",
"description": "Result Map",
"properties": {
"total_rows": {
"type": "number"
},
"offset": {
"type": "number"
},
"size": {
"type": "number"
},
"rows": {
"type": "array",
"items": {
"$ref": "#/components/schemas/resultmap"
}
}
}
}
Query
Queries for matches
POST /logs/query
Parameters
| Name |
Required |
Type |
Description |
| sort |
false |
object |
Defines how to sort fields in the result set |
| skip |
false |
number |
Skips the result set cursor ahead the specified number of records |
| limit |
false |
number |
Specifies the number of records to be handed back in the result set |
This method supports pagination.
Response
{
"type": "object",
"description": "Result Map",
"properties": {
"total_rows": {
"type": "number"
},
"offset": {
"type": "number"
},
"size": {
"type": "number"
},
"rows": {
"type": "array",
"items": {
"$ref": "#/components/schemas/resultmap"
}
}
}
}
Query
Queries for matches
POST /jobs/query
Parameters
| Name |
Required |
Type |
Description |
| sort |
false |
object |
Defines how to sort fields in the result set |
| skip |
false |
number |
Skips the result set cursor ahead the specified number of records |
| limit |
false |
number |
Specifies the number of records to be handed back in the result set |
This method supports pagination.
Response
{
"type": "object",
"description": "Result Map",
"properties": {
"total_rows": {
"type": "number"
},
"offset": {
"type": "number"
},
"size": {
"type": "number"
},
"rows": {
"type": "array",
"items": {
"$ref": "#/components/schemas/resultmap"
}
}
}
}
Query
Queries for matches
POST /activities/query
Parameters
| Name |
Required |
Type |
Description |
| sort |
false |
object |
Defines how to sort fields in the result set |
| skip |
false |
number |
Skips the result set cursor ahead the specified number of records |
| limit |
false |
number |
Specifies the number of records to be handed back in the result set |
This method supports pagination.
Response
{
"type": "object",
"description": "Result Map",
"properties": {
"total_rows": {
"type": "number"
},
"offset": {
"type": "number"
},
"size": {
"type": "number"
},
"rows": {
"type": "array",
"items": {
"$ref": "#/components/schemas/resultmap"
}
}
}
}
Read ACL
Reads the ACL for the platform
GET /acl/list
Parameters
This function has no parameters.
Response
{
"type": "object",
"description": "Result Map of ACL entries",
"properties": {
"total_rows": {
"type": "number"
},
"offset": {
"type": "number"
},
"size": {
"type": "number"
},
"rows": {
"type": "array",
"items": {
"type": "object",
"properties": {
"_doc": {
"type": "string",
"title": "Principal ID"
},
"name": {
"type": "string",
"title": "Principal Name"
},
"type": {
"type": "string",
"title": "Principal Type"
},
"domainId": {
"type": "string"
},
"domainQualifiedId": {
"type": "string"
},
"domainQualifiedName": {
"type": "string"
},
"principalId": {
"type": "string",
"title": "Principal ID"
},
"userEmail": {
"type": "string"
},
"userFirstName": {
"type": "string"
},
"userLastName": {
"type": "string"
},
"authorities": {
"type": "array",
"title": "Authorities",
"items": {
"type": "string",
"title": "Authority Key"
}
}
}
}
}
}
}
Read ACL for Principal
Reads the ACL for the platform and specific actor
GET /acl
Parameters
| Name |
Required |
Type |
Description |
| id |
true |
string |
|
Response
{
"type": "object",
"description": "Result Map of Authority Keys",
"properties": {
"total_rows": {
"type": "number"
},
"offset": {
"type": "number"
},
"size": {
"type": "number"
},
"rows": {
"type": "array",
"items": {
"type": "string",
"description": "Authority Key"
}
}
}
}
Read API Keys
Retrieves API Keys within the current platform
GET /apikeys
Parameters
This function has no parameters.
Read API Usage
Retrieves API Usage information for the current platform
GET /api/usage
Parameters
This function has no parameters.
Read Activity
GET /activities/{activityId}
Parameters
| Name |
Required |
Type |
Description |
| activityId |
true |
string |
|
Read Attachment
GET /jobs/{jobId}/result/attachments/{attachmentId}
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
| attachmentId |
true |
string |
|
Read Attachment
GET /jobs/{jobId}/data/attachments/{attachmentId}
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
| attachmentId |
true |
string |
|
Read Authorities Report
Read the Authorities Report for the specified platform
POST /authorities
Parameters
This function has no parameters.
Response
{
"type": "object",
"description": "Authority Report",
"properties": {
"principalId": {
"type": "object",
"properties": {
"id": {
"type": "object",
"properties": {
"role-key": {
"type": "string"
},
"principal": {
"type": "string"
},
"permissioned": {
"type": "string"
},
"inheritsFrom": {
"type": "object",
"properties": {
"id": {
"type": "string"
},
"principal": {
"type": "string"
},
"permissioned": {
"type": "string"
}
}
}
}
}
}
}
}
}
Read Data Job
GET /jobs/{jobId}/data
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
Read Dependson Job
GET /jobs/{jobId}/dependson
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
Read Download
GET /ref/exports/{exportId}/download/{index}
Parameters
| Name |
Required |
Type |
Description |
| exportId |
true |
string |
|
| index |
true |
string |
|
Read Download Export
GET /ref/exports/{exportId}/download
Parameters
| Name |
Required |
Type |
Description |
| exportId |
true |
string |
|
Read Info
GET /info
Parameters
This function has no parameters.
Read Job
Reads a job. Background operations such as exports and imports return a job ID that you can poll with this call.
GET /jobs/{jobId}
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
The ID of the job |
The job's state settles at FINISHED if it completes successfully or ERROR if there is a problem.
Read Log
GET /logs/{logEntryId}
Parameters
| Name |
Required |
Type |
Description |
| logEntryId |
true |
string |
The ID of the log entry |
Read Log
GET /jobs/{jobId}/logs/{id}
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
| jobId |
true |
string |
|
Read Platform
Reads an instance of a Platform
GET /
Parameters
This function has no parameters.
Response
{
"type": "object",
"extends": "datastore",
"description": "Platform",
"properties": {
"ownerRegistrarId": {
"type": "string"
},
"ownerTenantId": {
"type": "string"
},
"platformSize": {
"type": "number"
},
"platformObjectCount": {
"type": "number"
},
"sessionTimeout": {
"type": "number"
},
"authenticationMaxAttempts": {
"type": "number"
},
"authenticationResetTimeout": {
"type": "number"
},
"antivirusEnabled": {
"type": "boolean"
},
"accessTokenValidity": {
"type": "number"
},
"refreshTokenValidity": {
"type": "number"
},
"refreshTokenRaceConditionWindowMs": {
"type": "number"
},
"title": null,
"description": null,
"datastoreId": null,
"datastoreTypeId": null,
"enableAuthorities": null,
"size": null,
"maxsize": null,
"objectcount": null,
"locked": null,
"lockedBy": null,
"statisticsDate": null,
"statisticsDirty": null,
"binaryStorageProviderType": null,
"_doc": null,
"_system": null
}
}
Read Poll Job
GET /jobs/{jobId}/poll
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
| since |
false |
string |
|
Read Ref
POST /ref/read
Parameters
This function has no parameters.
Read Result Job
GET /jobs/{jobId}/result
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
Read Role
Reads a role for the current platform
GET /roles/{roleKeyOrId}
Parameters
| Name |
Required |
Type |
Description |
| roleKeyOrId |
true |
string |
|
| inherited |
false |
string |
|
Response
{
"$ref": "#/components/schemas/"
}
Read Status Export
GET /ref/exports/{exportId}/status
Parameters
| Name |
Required |
Type |
Description |
| exportId |
true |
string |
|
Remove Team Member
Remove a principal from a team's membership list
POST /teams/{teamKey}/members/remove
Parameters
| Name |
Required |
Type |
Description |
| teamKey |
true |
string |
The key identifier for the team |
| id |
true |
string |
|
Response
{
"type": "object",
"description": "Status of Operation",
"properties": {
"ok": {
"type": "boolean",
"description": "Indicates whether the operation succeeded or not"
}
}
}
Revoke Authority
Revokes an authority against the specified platform from a given user
POST /authorities/{authorityId}/revoke
Parameters
| Name |
Required |
Type |
Description |
| authorityId |
true |
string |
The ID or authority key for the authority |
| id |
true |
string |
|
Response
{
"type": "object",
"description": "Status of Operation",
"properties": {
"ok": {
"type": "boolean",
"description": "Indicates whether the operation succeeded or not"
}
}
}
Revoke Authority from Team
Revokes an Authority from a Team for the given platform
POST /teams/{teamKey}/authorities/{authorityId}/revoke
Parameters
| Name |
Required |
Type |
Description |
| teamKey |
true |
string |
The key identifier for the team |
| authorityId |
true |
string |
The ID or authority key for the authority |
Response
{
"type": "object",
"description": "Status of Operation",
"properties": {
"ok": {
"type": "boolean",
"description": "Indicates whether the operation succeeded or not"
}
}
}
Search Projects
GET /projects/search
Parameters
| Name |
Required |
Type |
Description |
| text |
true |
string |
|
Search Projects
POST /projects/search
Parameters
This function has no parameters.
Start Exports
POST /ref/exports/start
Parameters
This function has no parameters.
Start Verify
POST /ref/deployments/verify/start
Parameters
This function has no parameters.
Summarize Access Policy
Retrieves an access policy summary for a Team on the given platform
GET /teams/{teamKey}/access/policies/summary
Parameters
| Name |
Required |
Type |
Description |
| teamKey |
true |
string |
The key identifier for the team |
| scope |
false |
string |
|
| info |
false |
string |
|
| order |
false |
string |
|
Response
{
"type": "object",
"description": "Result Map",
"properties": {
"total_rows": {
"type": "number"
},
"offset": {
"type": "number"
},
"size": {
"type": "number"
},
"rows": {
"type": "array",
"items": {
"type": "object"
}
}
}
}
Summary Default
POST /queues/default/summary
Parameters
This function has no parameters.
Update Attachment
POST /jobs/{jobId}/result/attachments/{attachmentId}
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
| attachmentId |
true |
string |
|
Update Attachment
POST /jobs/{jobId}/data/attachments/{attachmentId}
Parameters
| Name |
Required |
Type |
Description |
| jobId |
true |
string |
|
| attachmentId |
true |
string |
|
Update Platform
Updates an existing Platform
PUT /
Parameters
This function has no parameters.
Response
{
"type": "object",
"description": "Status of Operation",
"properties": {
"ok": {
"type": "boolean",
"description": "Indicates whether the operation succeeded or not"
}
}
}
Update Platform
Updates an existing Platform
POST /update
Parameters
This function has no parameters.
Response
{
"type": "object",
"description": "Status of Operation",
"properties": {
"ok": {
"type": "boolean",
"description": "Indicates whether the operation succeeded or not"
}
}
}
Update Role
Updates a role for the currnet platform
PUT /roles/{roleKeyOrId}
Parameters
| Name |
Required |
Type |
Description |
| roleKeyOrId |
true |
string |
|
| HTTP Payload |
true |
string |
HTTP Payload |
Response
{
"type": "object",
"description": "Status of Operation",
"properties": {
"ok": {
"type": "boolean",
"description": "Indicates whether the operation succeeded or not"
}
}
}
Update Role
Updates a role for the current platform
POST /roles/{roleKeyOrId}/update
Parameters
| Name |
Required |
Type |
Description |
| roleKeyOrId |
true |
string |
|
| HTTP Payload |
true |
string |
HTTP Payload |
Response
{
"type": "object",
"description": "Status of Operation",
"properties": {
"ok": {
"type": "boolean",
"description": "Indicates whether the operation succeeded or not"
}
}
}
Update a Team
Updates a Team against the given platform
PUT /teams/{teamKey}
Parameters
| Name |
Required |
Type |
Description |
| teamKey |
true |
string |
The key identifier for the team |
Response
{
"type": "object",
"description": "Status of Operation",
"properties": {
"ok": {
"type": "boolean",
"description": "Indicates whether the operation succeeded or not"
}
}
}
Upload Attachment
Uploads an attachment
POST /tenant/attachments/{attachmentId}
Parameters
| Name |
Required |
Type |
Description |
| attachmentId |
true |
string |
|
Schema
{
"type": "object",
"extends": "datastore",
"description": "Platform",
"properties": {
"ownerRegistrarId": {
"type": "string"
},
"ownerTenantId": {
"type": "string"
},
"platformSize": {
"type": "number"
},
"platformObjectCount": {
"type": "number"
},
"sessionTimeout": {
"type": "number"
},
"authenticationMaxAttempts": {
"type": "number"
},
"authenticationResetTimeout": {
"type": "number"
},
"antivirusEnabled": {
"type": "boolean"
},
"accessTokenValidity": {
"type": "number"
},
"refreshTokenValidity": {
"type": "number"
},
"refreshTokenRaceConditionWindowMs": {
"type": "number"
},
"title": null,
"description": null,
"datastoreId": null,
"datastoreTypeId": null,
"enableAuthorities": null,
"size": null,
"maxsize": null,
"objectcount": null,
"locked": null,
"lockedBy": null,
"statisticsDate": null,
"statisticsDirty": null,
"binaryStorageProviderType": null,
"_doc": null,
"_system": null
},
"id": "platform"
}